@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from dataclasses import dataclass
 from dataclasses import field as dc_field
 from itertools import zip_longest
@@ -71,7 +73,10 @@ class SuperSampler(_Antialiaser, Scaler):
     ) -> vs.VideoNode:
         clip = self.preprocess_clip(clip)
 
-        assert clip.format
+        assert clip.format and clip.width and clip.height
+
+        if (clip.width, clip.height) == (width, height):
+            return clip
 
         kwargs = self.get_aa_args(clip, **kwargs) | self.get_ss_args(clip, **kwargs) | kwargs
 
@@ -81,9 +86,6 @@ class SuperSampler(_Antialiaser, Scaler):
 
         cdivw, cdivh = 1 << clip.format.subsampling_w, 1 << clip.format.subsampling_h
 
-        if ((divw < 1) or (divw < 1)) or divw == divh == 1:
-            raise ValueError(f'{self.__class__.__name__}.scale: width and height must be bigger than clip\'s size.')
-
         upscaled = clip
 
         def _transpose(before: bool, is_width: int, y: int, x: int) -> None:
@@ -198,9 +200,9 @@ class DoubleRater(SingleRater):
         original_field = int(self.field)
 
         self.field = 0
-        aa0 = super().aa(clip, y, x, **kwargs)
+        aa0 = super()._aa(clip, y, x, **kwargs)
         self.field = 1
-        aa1 = super().aa(clip, y, x, **kwargs)
+        aa1 = super()._aa(clip, y, x, **kwargs)
 
         self.field = original_field
 
