@@ -1,16 +1,22 @@
+from __future__ import annotations
+
 import vapoursynth as vs
 from vsexprtools import PlanesT, norm_expr_planes, normalise_planes
-from vskernels import Catrom, Kernel, Spline144
+from vskernels import Catrom, Spline144
+from vskernels.kernels.abstract import Scaler
 from vsmask.edge import EdgeDetect, ScharrTCanny
 from vsrgtools import RepairMode, box_blur, contrasharpening_median, median_clips, repair
 from vsutil import get_depth, get_peak_value, get_w, join, scale_value, split
 
-from .abstract import SingleRater, SuperSampler
+from .abstract import SingleRater
 from .antialiasers import Eedi3SR, Nnedi3SR, Nnedi3SS
 from .enums import AADirection
 
 __all__ = [
-    'upscaled_sraa', 'transpose_aa', 'clamp_aa', 'masked_clamp_aa', 'fine_aa'
+    'upscaled_sraa',
+    'transpose_aa',
+    'clamp_aa', 'masked_clamp_aa',
+    'fine_aa'
 ]
 
 core = vs.core
@@ -19,12 +25,19 @@ core = vs.core
 def upscaled_sraa(
     clip: vs.VideoNode, rfactor: float = 1.5,
     width: int | None = None, height: int | None = None,
-    ssfunc: SuperSampler = Nnedi3SS(), aafunc: SingleRater = Eedi3SR(),
+    ssfunc: Scaler = Nnedi3SS(), aafunc: SingleRater = Eedi3SR(),
     direction: AADirection = AADirection.BOTH,
-    downscaler: Kernel = Catrom()
+    downscaler: Scaler = Catrom(), planes: PlanesT = 0
 ) -> vs.VideoNode:
     """
-    :param clip:            Clip to process, only luma will be processed.
+    Super-sampled single-rate AA for heavy aliasing and broken line-art.
+
+    It works by super-sampling the clip, performing AA, and then downscaling again.
+    Downscaling can be disabled by setting `downscaler` to `None`, returning the super-sampled luma clip.
+    The dimensions of the downscaled clip can also be adjusted by setting `height` or `width`.
+    Setting either `height`, `width` or 1,2 in planes will also scale the chroma accordingly.
+
+    :param clip:            Clip to process.
     :param rfactor:         Image enlargement factor.
                             It is not recommended to go below 1.3
     :param width:           Target resolution width. If None, determined from `height`.
@@ -32,6 +45,7 @@ def upscaled_sraa(
     :param ssfunc:          Super-sampler used for upscaling before AA.
     :param aafunc:          Downscaler to use after super-sampling.
     :param aafun:           Function used to antialias after super-sampling.
+    :param planes:          Planes to do antialiasing on.
 
     :return:                Antialiased clip.
 
@@ -39,7 +53,21 @@ def upscaled_sraa(
     """
     assert clip.format
 
-    work_clip, *chroma = split(clip)
+    planes = normalise_planes(clip, planes)
+
+    if height is None:
+        height = clip.height
+
+    if width is None:
+        if height == clip.height:
+            width = clip.width
+        else:
+            width = get_w(height, aspect_ratio=clip.width / clip.height)
+
+    aa_chroma = 1 in planes or 2 in planes
+    scale_chroma = ((clip.width, clip.height) != (width, height)) or aa_chroma
+
+    work_clip, *chroma = [clip] if scale_chroma else split(clip)
 
     if rfactor <= 1:
         raise ValueError('upscaled_sraa: rfactor must be above 1!')
@@ -47,25 +75,17 @@ def upscaled_sraa(
     ssw = (round(work_clip.width * rfactor) + 1) & ~1
     ssh = (round(work_clip.height * rfactor) + 1) & ~1
 
-    if height is None:
-        height = work_clip.height
+    up = ssfunc.scale(work_clip, ssw, ssh)
+    up, *chroma = [up] if aa_chroma else (split(up) if scale_chroma else [up, *chroma])
 
-    if width is None:
-        if height == work_clip.height:
-            width = work_clip.width
-        else:
-            width = get_w(height, aspect_ratio=clip.width / clip.height)
-
-    up_y = ssfunc.scale(work_clip, ssw, ssh)
-
-    aa_y = aafunc.aa(up_y, *direction.to_yx())
+    aa = aafunc.aa(up, *direction.to_yx())
 
     if downscaler:
-        aa_y = downscaler.scale(aa_y, width, height)
-    elif not chroma or (clip.width, clip.height) != (width, height):
-        return aa_y
+        aa = downscaler.scale(aa, width, height)
+    elif not chroma:
+        return aa
 
-    return join([aa_y, *chroma], clip.format.color_family)
+    return join([aa, *chroma], clip.format.color_family)
 
 
 def transpose_aa(clip: vs.VideoNode, aafunc: SingleRater) -> vs.VideoNode:
@@ -118,7 +138,7 @@ def clamp_aa(
         thr = strength / 219
 
     if thr == 0:
-        return median_clips([src, weak, strong], planes)
+        return median_clips(src, weak, strong, planes=planes)
 
     expr = f'x y - XYD! XYD@ x z - XZD! XZD@ xor x XYD@ abs XZD@ abs < z y {thr} + min y {thr} - max z ? ?'
 
@@ -194,6 +214,7 @@ def fine_aa(
     Taa and optionally repair clip that results in overall lighter anti-aliasing, downscaled with Spline kernel.
 
     :param clip:            Clip to process.
+    :param taa:             Whether to perform a normal or transposed aa
     :param singlerater:     Singlerater used for aa.
     :param rep:             Repair mode.
 
